# IFRC GO Database Library

The [IFRC GO](https://go.ifrc.org) platform helps manage the global portfolio of work carried out by the nearly 200 national societies that make up the Red Cross Red Crescent Movement. The platform helps manage: 

- Emergency Appeals
- Surge Alerts
- Deployments
- National Society Information
- ...and much more!

This python library is intended to help make it easier to interact with the database by offering access to a number of functions and classes to query, organize, and extract the data you need. 